/*
 * This file is part of jdbw (http://code.google.com/p/jdbw/).
 * 
 * jdbw is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright (C) 2007-2012 Martin Berglund
 */

package com.googlecode.jdbw.server.mysql;

/**
 * This driver descriptor overrides the default MySQL JDBC driver descriptor and
 * adds certain common parameters to the URL. These are:
 * <ul>
 * <li>{@code useUnicode=yes}
 * <li>{@code characterEncoding=UTF-8}
 * <li>{@code rewriteBatchedStatements=true}
 * <li>{@code continueBatchOnError=false}
 * <li>{@code allowMultiQueries=true}
 * <li>{@code useCompression=true}
 * <li>{@code zeroDateTimeBehavior=convertToNull}
 * </ul>
 * @see MySQLDefaultJDBCDriverDescriptor
 * @author Martin Berglund
 */
public class MySQLCommonJDBCDriverDescriptor extends MySQLDefaultJDBCDriverDescriptor {
    @Override
    public String formatJDBCUrl(String host, int port, String defaultCatalog) {
        return super.formatJDBCUrl(host, port, defaultCatalog) +
                "?useUnicode=yes"
                + "&characterEncoding=UTF-8"
                + "&rewriteBatchedStatements=true"
                + "&continueBatchOnError=false"
                + "&allowMultiQueries=true"
                + "&useCompression=true"
                + "&zeroDateTimeBehavior=convertToNull";
    }
}
